@@ -3,7 +3,7 @@ use anyhow::Result;
 use crate::Client;
 
 pub struct CustomIds {
-    client: Client,
+    pub client: Client,
 }
 
 impl CustomIds {
@@ -55,10 +55,7 @@ impl CustomIds {
     ) -> Result<()> {
         let url = "/custom-id-provider/application-link".to_string();
         self.client
-            .post(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .post(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
@@ -128,10 +125,7 @@ impl CustomIds {
         );
 
         self.client
-            .post(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .post(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 }
