@@ -25,7 +25,7 @@ impl Receipts {
      * * `to_date: chrono::DateTime<chrono::Utc>` -- Filter for receipts related to transactions which occurred before the specified date.
      * * `created_after: chrono::DateTime<chrono::Utc>` -- Filter for receipts that were created after the specified date.
      * * `created_before: chrono::DateTime<chrono::Utc>` -- Filter for receipts that were created before the specified date.
-     * * `start: Option<uuid::Uuid>` -- The ID of the last entity of the previous page, used for pagination to get the next page.
+     * * `start: &str` -- The ID of the last entity of the previous page, used for pagination to get the next page.
      * * `page_size: f64` -- The number of results to be returned in each page. The value must be between 2 and 10,000. If not specified, the default will be 1,000.
      */
     pub async fn get_page(
@@ -34,7 +34,7 @@ impl Receipts {
         to_date: Option<chrono::DateTime<chrono::Utc>>,
         created_after: Option<chrono::DateTime<chrono::Utc>>,
         created_before: Option<chrono::DateTime<chrono::Utc>>,
-        start: Option<uuid::Uuid>,
+        start: &str,
         page_size: f64,
     ) -> Result<Vec<crate::types::Receipt>> {
         let mut query_args: Vec<(String, String)> = Default::default();
@@ -50,8 +50,8 @@ impl Receipts {
         if !page_size.to_string().is_empty() {
             query_args.push(("page_size".to_string(), page_size.to_string()));
         }
-        if let Some(u) = start {
-            query_args.push(("start".to_string(), u.to_string()));
+        if !start.is_empty() {
+            query_args.push(("start".to_string(), start.to_string()));
         }
         if let Some(date) = to_date {
             query_args.push(("to_date".to_string(), date.to_rfc3339()));
