@@ -22,8 +22,8 @@ impl Transactions {
      * **Parameters:**
      *
      * * `authorization: &str` -- The OAuth2 token header.
-     * * `department_id: Option<uuid::Uuid>` -- The ID of the last entity of the previous page, used for pagination to get the next page.
-     * * `location_id: Option<uuid::Uuid>` -- The ID of the last entity of the previous page, used for pagination to get the next page.
+     * * `department_id: &str` -- The OAuth2 token header.
+     * * `location_id: &str` -- The OAuth2 token header.
      * * `from_date: chrono::DateTime<chrono::Utc>`
      * * `to_date: chrono::DateTime<chrono::Utc>`
      * * `merchant_id: &str` -- The OAuth2 token header.
@@ -35,14 +35,14 @@ impl Transactions {
      * * `state: &str` -- The OAuth2 token header.
      * * `min_amount: f64` -- The number of results to be returned in each page. The value must be between 2 and 10,000. If not specified, the default will be 1,000.
      * * `max_amount: f64` -- The number of results to be returned in each page. The value must be between 2 and 10,000. If not specified, the default will be 1,000.
-     * * `start: Option<uuid::Uuid>` -- The ID of the last entity of the previous page, used for pagination to get the next page.
+     * * `start: &str` -- The ID of the last entity of the previous page, used for pagination to get the next page.
      * * `page_size: f64` -- The number of results to be returned in each page. The value must be between 2 and 10,000. If not specified, the default will be 1,000.
      * * `requires_memo: bool` -- Filters for transactions which require a memo, but do not have one. This can only be set to true.
      */
     pub async fn get_page(
         &self,
-        department_id: Option<uuid::Uuid>,
-        location_id: Option<uuid::Uuid>,
+        department_id: &str,
+        location_id: &str,
         from_date: Option<chrono::DateTime<chrono::Utc>>,
         to_date: Option<chrono::DateTime<chrono::Utc>>,
         merchant_id: &str,
@@ -54,19 +54,19 @@ impl Transactions {
         state: &str,
         min_amount: f64,
         max_amount: f64,
-        start: Option<uuid::Uuid>,
+        start: &str,
         page_size: f64,
         requires_memo: bool,
     ) -> Result<Vec<crate::types::Data>> {
         let mut query_args: Vec<(String, String)> = Default::default();
-        if let Some(u) = department_id {
-            query_args.push(("department_id".to_string(), u.to_string()));
+        if !department_id.is_empty() {
+            query_args.push(("department_id".to_string(), department_id.to_string()));
         }
         if let Some(date) = from_date {
             query_args.push(("from_date".to_string(), date.to_rfc3339()));
         }
-        if let Some(u) = location_id {
-            query_args.push(("location_id".to_string(), u.to_string()));
+        if !location_id.is_empty() {
+            query_args.push(("location_id".to_string(), location_id.to_string()));
         }
         if !max_amount.to_string().is_empty() {
             query_args.push(("max_amount".to_string(), max_amount.to_string()));
@@ -110,8 +110,8 @@ impl Transactions {
         if !sk_category_id.is_empty() {
             query_args.push(("sk_category_id".to_string(), sk_category_id.to_string()));
         }
-        if let Some(u) = start {
-            query_args.push(("start".to_string(), u.to_string()));
+        if !start.is_empty() {
+            query_args.push(("start".to_string(), start.to_string()));
         }
         if !state.is_empty() {
             query_args.push(("state".to_string(), state.to_string()));
@@ -139,8 +139,8 @@ impl Transactions {
      */
     pub async fn get_all(
         &self,
-        department_id: Option<uuid::Uuid>,
-        location_id: Option<uuid::Uuid>,
+        department_id: &str,
+        location_id: &str,
         from_date: Option<chrono::DateTime<chrono::Utc>>,
         to_date: Option<chrono::DateTime<chrono::Utc>>,
         merchant_id: &str,
@@ -155,14 +155,14 @@ impl Transactions {
         requires_memo: bool,
     ) -> Result<Vec<crate::types::Data>> {
         let mut query_args: Vec<(String, String)> = Default::default();
-        if let Some(u) = department_id {
-            query_args.push(("department_id".to_string(), u.to_string()));
+        if !department_id.is_empty() {
+            query_args.push(("department_id".to_string(), department_id.to_string()));
         }
         if let Some(date) = from_date {
             query_args.push(("from_date".to_string(), date.to_rfc3339()));
         }
-        if let Some(u) = location_id {
-            query_args.push(("location_id".to_string(), u.to_string()));
+        if !location_id.is_empty() {
+            query_args.push(("location_id".to_string(), location_id.to_string()));
         }
         if !max_amount.to_string().is_empty() {
             query_args.push(("max_amount".to_string(), max_amount.to_string()));
