@@ -99,8 +99,12 @@ pub struct User {
     /**
      * Ramp User
      */
-    #[serde(default, skip_serializing_if = "Option::is_none")]
-    pub business_id: Option<uuid::Uuid>,
+    #[serde(
+        default,
+        skip_serializing_if = "String::is_empty",
+        deserialize_with = "crate::utils::deserialize_null_string::deserialize"
+    )]
+    pub business_id: String,
     /**
      * Ramp User
      */
@@ -129,10 +133,14 @@ pub struct User {
     )]
     pub first_name: String,
     /**
-     * The ID of the last entity of the previous page, used for pagination to get the next page.
+     * The OAuth2 token header
      */
-    #[serde()]
-    pub id: uuid::Uuid,
+    #[serde(
+        default,
+        skip_serializing_if = "String::is_empty",
+        deserialize_with = "crate::utils::deserialize_null_string::deserialize"
+    )]
+    pub id: String,
     /**
      * The OAuth2 token header
      */
@@ -176,20 +184,32 @@ pub struct User {
 #[derive(Serialize, Deserialize, PartialEq, Debug, Clone, JsonSchema)]
 pub struct PatchUsersRequest {
     /**
-     * The ID of the last entity of the previous page, used for pagination to get the next page.
+     * The OAuth2 token header
      */
-    #[serde(default, skip_serializing_if = "Option::is_none")]
-    pub department_id: Option<uuid::Uuid>,
+    #[serde(
+        default,
+        skip_serializing_if = "String::is_empty",
+        deserialize_with = "crate::utils::deserialize_null_string::deserialize"
+    )]
+    pub department_id: String,
     /**
-     * The ID of the last entity of the previous page, used for pagination to get the next page.
+     * The OAuth2 token header
      */
-    #[serde(default, skip_serializing_if = "Option::is_none")]
-    pub direct_manager_id: Option<uuid::Uuid>,
+    #[serde(
+        default,
+        skip_serializing_if = "String::is_empty",
+        deserialize_with = "crate::utils::deserialize_null_string::deserialize"
+    )]
+    pub direct_manager_id: String,
     /**
-     * The ID of the last entity of the previous page, used for pagination to get the next page.
+     * The OAuth2 token header
      */
-    #[serde(default, skip_serializing_if = "Option::is_none")]
-    pub location_id: Option<uuid::Uuid>,
+    #[serde(
+        default,
+        skip_serializing_if = "String::is_empty",
+        deserialize_with = "crate::utils::deserialize_null_string::deserialize"
+    )]
+    pub location_id: String,
     #[serde(default, skip_serializing_if = "Option::is_none")]
     pub role: Option<Role>,
 }
@@ -207,10 +227,14 @@ pub struct Page {
 #[derive(Serialize, Deserialize, PartialEq, Debug, Clone, JsonSchema)]
 pub struct CardHolder {
     /**
-     * The ID of the last entity of the previous page, used for pagination to get the next page.
+     * The OAuth2 token header
      */
-    #[serde()]
-    pub department_id: uuid::Uuid,
+    #[serde(
+        default,
+        skip_serializing_if = "String::is_empty",
+        deserialize_with = "crate::utils::deserialize_null_string::deserialize"
+    )]
+    pub department_id: String,
     /**
      * The OAuth2 token header
      */
@@ -239,10 +263,14 @@ pub struct CardHolder {
     )]
     pub last_name: String,
     /**
-     * The ID of the last entity of the previous page, used for pagination to get the next page.
+     * The OAuth2 token header
      */
-    #[serde()]
-    pub location_id: uuid::Uuid,
+    #[serde(
+        default,
+        skip_serializing_if = "String::is_empty",
+        deserialize_with = "crate::utils::deserialize_null_string::deserialize"
+    )]
+    pub location_id: String,
     /**
      * The OAuth2 token header
      */
@@ -320,10 +348,14 @@ pub struct PolicyViolations {
     )]
     pub created_at: Option<chrono::DateTime<chrono::Utc>>,
     /**
-     * The ID of the last entity of the previous page, used for pagination to get the next page.
+     * The OAuth2 token header
      */
-    #[serde(default, skip_serializing_if = "Option::is_none")]
-    pub id: Option<uuid::Uuid>,
+    #[serde(
+        default,
+        skip_serializing_if = "String::is_empty",
+        deserialize_with = "crate::utils::deserialize_null_string::deserialize"
+    )]
+    pub id: String,
     /**
      * The OAuth2 token header
      */
@@ -387,10 +419,14 @@ pub struct Disputes {
     )]
     pub created_at: Option<chrono::DateTime<chrono::Utc>>,
     /**
-     * The ID of the last entity of the previous page, used for pagination to get the next page.
+     * The OAuth2 token header
      */
-    #[serde(default, skip_serializing_if = "Option::is_none")]
-    pub id: Option<uuid::Uuid>,
+    #[serde(
+        default,
+        skip_serializing_if = "String::is_empty",
+        deserialize_with = "crate::utils::deserialize_null_string::deserialize"
+    )]
+    pub id: String,
     /**
      * The OAuth2 token header
      */
@@ -428,10 +464,14 @@ pub struct Data {
     #[serde()]
     pub card_holder: CardHolder,
     /**
-     * The ID of the last entity of the previous page, used for pagination to get the next page.
+     * The OAuth2 token header
      */
-    #[serde()]
-    pub card_id: uuid::Uuid,
+    #[serde(
+        default,
+        skip_serializing_if = "String::is_empty",
+        deserialize_with = "crate::utils::deserialize_null_string::deserialize"
+    )]
+    pub card_id: String,
     /**
      * Ramp transaction
      */
@@ -442,10 +482,14 @@ pub struct Data {
     )]
     pub disputes: Vec<Disputes>,
     /**
-     * The ID of the last entity of the previous page, used for pagination to get the next page.
+     * The OAuth2 token header
      */
-    #[serde()]
-    pub id: uuid::Uuid,
+    #[serde(
+        default,
+        skip_serializing_if = "String::is_empty",
+        deserialize_with = "crate::utils::deserialize_null_string::deserialize"
+    )]
+    pub id: String,
     /**
      * Ramp transaction
      */
@@ -456,10 +500,14 @@ pub struct Data {
     )]
     pub memo: String,
     /**
-     * The ID of the last entity of the previous page, used for pagination to get the next page.
+     * The OAuth2 token header
      */
-    #[serde()]
-    pub merchant_id: uuid::Uuid,
+    #[serde(
+        default,
+        skip_serializing_if = "String::is_empty",
+        deserialize_with = "crate::utils::deserialize_null_string::deserialize"
+    )]
+    pub merchant_id: String,
     /**
      * The OAuth2 token header
      */
@@ -486,7 +534,7 @@ pub struct Data {
         skip_serializing_if = "Vec::is_empty",
         deserialize_with = "crate::utils::deserialize_null_vector::deserialize"
     )]
-    pub receipts: Vec<uuid::Uuid>,
+    pub receipts: Vec<String>,
     /**
      * The number of results to be returned in each page. The value must be between 2 and 10,000. If not specified, the default will be 1,000.
      */
@@ -553,8 +601,12 @@ pub struct Location {
     /**
      * Ramp location
      */
-    #[serde(default, skip_serializing_if = "Option::is_none")]
-    pub id: Option<uuid::Uuid>,
+    #[serde(
+        default,
+        skip_serializing_if = "String::is_empty",
+        deserialize_with = "crate::utils::deserialize_null_string::deserialize"
+    )]
+    pub id: String,
     /**
      * Ramp location
      */
@@ -611,8 +663,12 @@ pub struct Department {
     /**
      * Ramp Department
      */
-    #[serde(default, skip_serializing_if = "Option::is_none")]
-    pub id: Option<uuid::Uuid>,
+    #[serde(
+        default,
+        skip_serializing_if = "String::is_empty",
+        deserialize_with = "crate::utils::deserialize_null_string::deserialize"
+    )]
+    pub id: String,
     /**
      * Ramp Department
      */
@@ -636,19 +692,6 @@ pub struct GetDepartmentsResponse {
     pub page: GetLocationResponsePage,
 }
 
-#[derive(Serialize, Default, Deserialize, PartialEq, Debug, Clone, JsonSchema)]
-pub struct GetCardsResponsePage {
-    /**
-     * The ID of the last entity of the previous page, used for pagination to get the next page.
-     */
-    #[serde(
-        default,
-        skip_serializing_if = "String::is_empty",
-        deserialize_with = "crate::utils::deserialize_null_string::deserialize"
-    )]
-    pub next: String,
-}
-
 #[derive(Serialize, Deserialize, PartialEq, Debug, Clone, JsonSchema)]
 pub struct RecipientAddress {
     /**
@@ -846,13 +889,21 @@ pub struct Card {
     /**
      * Card data that holds mostly static information about a card.
      */
-    #[serde(default, skip_serializing_if = "Option::is_none")]
-    pub card_program_id: Option<uuid::Uuid>,
+    #[serde(
+        default,
+        skip_serializing_if = "String::is_empty",
+        deserialize_with = "crate::utils::deserialize_null_string::deserialize"
+    )]
+    pub card_program_id: String,
     /**
      * Card data that holds mostly static information about a card.
      */
-    #[serde(default, skip_serializing_if = "Option::is_none")]
-    pub cardholder_id: Option<uuid::Uuid>,
+    #[serde(
+        default,
+        skip_serializing_if = "String::is_empty",
+        deserialize_with = "crate::utils::deserialize_null_string::deserialize"
+    )]
+    pub cardholder_id: String,
     /**
      * Card data that holds mostly static information about a card.
      */
@@ -879,8 +930,12 @@ pub struct Card {
     /**
      * Card data that holds mostly static information about a card.
      */
-    #[serde(default, skip_serializing_if = "Option::is_none")]
-    pub id: Option<uuid::Uuid>,
+    #[serde(
+        default,
+        skip_serializing_if = "String::is_empty",
+        deserialize_with = "crate::utils::deserialize_null_string::deserialize"
+    )]
+    pub id: String,
     /**
      * Card data that holds mostly static information about a card.
      */
@@ -914,16 +969,20 @@ pub struct GetCardsResponse {
     )]
     pub cards: Vec<Card>,
     #[serde(default)]
-    pub page: GetCardsResponsePage,
+    pub page: GetLocationResponsePage,
 }
 
 #[derive(Serialize, Deserialize, PartialEq, Debug, Clone, JsonSchema)]
 pub struct PatchResourcesCardsCardRequest {
     /**
-     * The ID of the last entity of the previous page, used for pagination to get the next page.
+     * The OAuth2 token header
      */
-    #[serde(default, skip_serializing_if = "Option::is_none")]
-    pub card_program_id: Option<uuid::Uuid>,
+    #[serde(
+        default,
+        skip_serializing_if = "String::is_empty",
+        deserialize_with = "crate::utils::deserialize_null_string::deserialize"
+    )]
+    pub card_program_id: String,
     /**
      * The OAuth2 token header
      */
@@ -945,10 +1004,14 @@ pub struct PatchResourcesCardsCardRequest {
 #[derive(Serialize, Deserialize, PartialEq, Debug, Clone, JsonSchema)]
 pub struct GetCustomProviderResponse {
     /**
-     * The ID of the last entity of the previous page, used for pagination to get the next page.
+     * The OAuth2 token header
      */
-    #[serde()]
-    pub custom_id_provider: uuid::Uuid,
+    #[serde(
+        default,
+        skip_serializing_if = "String::is_empty",
+        deserialize_with = "crate::utils::deserialize_null_string::deserialize"
+    )]
+    pub custom_id_provider: String,
 }
 
 #[derive(Serialize, Deserialize, PartialEq, Debug, Clone, JsonSchema)]
@@ -1130,10 +1193,14 @@ pub struct Business {
 #[derive(Serialize, Deserialize, PartialEq, Debug, Clone, JsonSchema)]
 pub struct PostResourcesCardPhysicalRequest {
     /**
-     * The ID of the last entity of the previous page, used for pagination to get the next page.
+     * The OAuth2 token header
      */
-    #[serde(default, skip_serializing_if = "Option::is_none")]
-    pub card_program_id: Option<uuid::Uuid>,
+    #[serde(
+        default,
+        skip_serializing_if = "String::is_empty",
+        deserialize_with = "crate::utils::deserialize_null_string::deserialize"
+    )]
+    pub card_program_id: String,
     /**
      * The OAuth2 token header
      */
@@ -1163,19 +1230,27 @@ pub struct PostResourcesCardPhysicalRequest {
     #[serde(default, skip_serializing_if = "Option::is_none")]
     pub spending_restrictions: Option<SpendingRestrictions>,
     /**
-     * The ID of the last entity of the previous page, used for pagination to get the next page.
+     * The OAuth2 token header
      */
-    #[serde(default, skip_serializing_if = "Option::is_none")]
-    pub user_id: Option<uuid::Uuid>,
+    #[serde(
+        default,
+        skip_serializing_if = "String::is_empty",
+        deserialize_with = "crate::utils::deserialize_null_string::deserialize"
+    )]
+    pub user_id: String,
 }
 
 #[derive(Serialize, Deserialize, PartialEq, Debug, Clone, JsonSchema)]
 pub struct PostResourcesCardVirtualRequest {
     /**
-     * The ID of the last entity of the previous page, used for pagination to get the next page.
+     * The OAuth2 token header
      */
-    #[serde(default, skip_serializing_if = "Option::is_none")]
-    pub card_program_id: Option<uuid::Uuid>,
+    #[serde(
+        default,
+        skip_serializing_if = "String::is_empty",
+        deserialize_with = "crate::utils::deserialize_null_string::deserialize"
+    )]
+    pub card_program_id: String,
     /**
      * The OAuth2 token header
      */
@@ -1200,10 +1275,14 @@ pub struct PostResourcesCardVirtualRequest {
     #[serde(default, skip_serializing_if = "Option::is_none")]
     pub spending_restrictions: Option<SpendingRestrictions>,
     /**
-     * The ID of the last entity of the previous page, used for pagination to get the next page.
+     * The OAuth2 token header
      */
-    #[serde(default, skip_serializing_if = "Option::is_none")]
-    pub user_id: Option<uuid::Uuid>,
+    #[serde(
+        default,
+        skip_serializing_if = "String::is_empty",
+        deserialize_with = "crate::utils::deserialize_null_string::deserialize"
+    )]
+    pub user_id: String,
 }
 
 #[derive(Serialize, Deserialize, PartialEq, Debug, Clone, JsonSchema)]
@@ -1356,10 +1435,14 @@ pub struct PostResourcesCardsCardSuspensionRequest {
 #[derive(Serialize, Deserialize, PartialEq, Debug, Clone, JsonSchema)]
 pub struct GetEntityTypeCustomRampResponse {
     /**
-     * The ID of the last entity of the previous page, used for pagination to get the next page.
+     * The OAuth2 token header
      */
-    #[serde(default, skip_serializing_if = "Option::is_none")]
-    pub ramp_id: Option<uuid::Uuid>,
+    #[serde(
+        default,
+        skip_serializing_if = "String::is_empty",
+        deserialize_with = "crate::utils::deserialize_null_string::deserialize"
+    )]
+    pub ramp_id: String,
 }
 
 #[derive(Serialize, Deserialize, PartialEq, Debug, Clone, JsonSchema)]
@@ -1396,10 +1479,14 @@ pub struct GetResourcesCardsDeferredResponseData {
     )]
     pub error: String,
     /**
-     * The ID of the last entity of the previous page, used for pagination to get the next page.
+     * The OAuth2 token header
      */
-    #[serde(default, skip_serializing_if = "Option::is_none")]
-    pub id: Option<uuid::Uuid>,
+    #[serde(
+        default,
+        skip_serializing_if = "String::is_empty",
+        deserialize_with = "crate::utils::deserialize_null_string::deserialize"
+    )]
+    pub id: String,
     /**
      * The OAuth2 token header
      */
@@ -1457,10 +1544,14 @@ pub struct GetResourcesCardsDeferredResponse {
     #[serde(default, skip_serializing_if = "Option::is_none")]
     pub data: Option<GetResourcesCardsDeferredResponseData>,
     /**
-     * The ID of the last entity of the previous page, used for pagination to get the next page.
+     * The OAuth2 token header
      */
-    #[serde(default, skip_serializing_if = "Option::is_none")]
-    pub id: Option<uuid::Uuid>,
+    #[serde(
+        default,
+        skip_serializing_if = "String::is_empty",
+        deserialize_with = "crate::utils::deserialize_null_string::deserialize"
+    )]
+    pub id: String,
     #[serde(default, skip_serializing_if = "Option::is_none")]
     pub status: Option<Status>,
 }
@@ -1553,8 +1644,12 @@ pub struct CardProgram {
     /**
      * Card Program data that serves as a template for creating new cards.
      */
-    #[serde(default, skip_serializing_if = "Option::is_none")]
-    pub id: Option<uuid::Uuid>,
+    #[serde(
+        default,
+        skip_serializing_if = "String::is_empty",
+        deserialize_with = "crate::utils::deserialize_null_string::deserialize"
+    )]
+    pub id: String,
     /**
      * Card Program data that serves as a template for creating new cards.
      */
@@ -1588,7 +1683,7 @@ pub struct GetCardProgramsResponse {
     )]
     pub card_programs: Vec<CardProgram>,
     #[serde(default)]
-    pub page: GetCardsResponsePage,
+    pub page: GetLocationResponsePage,
 }
 
 #[derive(Serialize, Deserialize, PartialEq, Debug, Clone, JsonSchema)]
@@ -1627,15 +1722,23 @@ pub struct PostResourcesCardProgramRequest {
 #[derive(Serialize, Deserialize, PartialEq, Debug, Clone, JsonSchema)]
 pub struct PostUsersDeferredRequest {
     /**
-     * The ID of the last entity of the previous page, used for pagination to get the next page.
+     * The OAuth2 token header
      */
-    #[serde(default, skip_serializing_if = "Option::is_none")]
-    pub department_id: Option<uuid::Uuid>,
+    #[serde(
+        default,
+        skip_serializing_if = "String::is_empty",
+        deserialize_with = "crate::utils::deserialize_null_string::deserialize"
+    )]
+    pub department_id: String,
     /**
-     * The ID of the last entity of the previous page, used for pagination to get the next page.
+     * The OAuth2 token header
      */
-    #[serde(default, skip_serializing_if = "Option::is_none")]
-    pub direct_manager_id: Option<uuid::Uuid>,
+    #[serde(
+        default,
+        skip_serializing_if = "String::is_empty",
+        deserialize_with = "crate::utils::deserialize_null_string::deserialize"
+    )]
+    pub direct_manager_id: String,
     /**
      * The OAuth2 token header
      */
@@ -1664,10 +1767,14 @@ pub struct PostUsersDeferredRequest {
     )]
     pub last_name: String,
     /**
-     * The ID of the last entity of the previous page, used for pagination to get the next page.
+     * The OAuth2 token header
      */
-    #[serde(default, skip_serializing_if = "Option::is_none")]
-    pub location_id: Option<uuid::Uuid>,
+    #[serde(
+        default,
+        skip_serializing_if = "String::is_empty",
+        deserialize_with = "crate::utils::deserialize_null_string::deserialize"
+    )]
+    pub location_id: String,
     /**
      * The OAuth2 token header
      */
@@ -1693,10 +1800,14 @@ pub struct GetUsersDeferredStatusResponseData {
     )]
     pub error: String,
     /**
-     * The ID of the last entity of the previous page, used for pagination to get the next page.
+     * The OAuth2 token header
      */
-    #[serde(default, skip_serializing_if = "Option::is_none")]
-    pub id: Option<uuid::Uuid>,
+    #[serde(
+        default,
+        skip_serializing_if = "String::is_empty",
+        deserialize_with = "crate::utils::deserialize_null_string::deserialize"
+    )]
+    pub id: String,
     /**
      * The OAuth2 token header
      */
@@ -1707,10 +1818,14 @@ pub struct GetUsersDeferredStatusResponseData {
     )]
     pub misc: String,
     /**
-     * The ID of the last entity of the previous page, used for pagination to get the next page.
+     * The OAuth2 token header
      */
-    #[serde(default, skip_serializing_if = "Option::is_none")]
-    pub user_id: Option<uuid::Uuid>,
+    #[serde(
+        default,
+        skip_serializing_if = "String::is_empty",
+        deserialize_with = "crate::utils::deserialize_null_string::deserialize"
+    )]
+    pub user_id: String,
 }
 
 ///
@@ -1759,18 +1874,30 @@ pub struct Receipt {
         deserialize_with = "crate::utils::date_time_format::deserialize"
     )]
     pub created_at: Option<chrono::DateTime<chrono::Utc>>,
-    #[serde(default, skip_serializing_if = "Option::is_none")]
-    pub id: Option<uuid::Uuid>,
+    #[serde(
+        default,
+        skip_serializing_if = "String::is_empty",
+        deserialize_with = "crate::utils::deserialize_null_string::deserialize"
+    )]
+    pub id: String,
     #[serde(
         default,
         skip_serializing_if = "Option::is_none",
         deserialize_with = "crate::utils::deserialize_empty_url::deserialize"
     )]
     pub receipt_url: Option<url::Url>,
-    #[serde(default, skip_serializing_if = "Option::is_none")]
-    pub transaction_id: Option<uuid::Uuid>,
-    #[serde(default, skip_serializing_if = "Option::is_none")]
-    pub user_id: Option<uuid::Uuid>,
+    #[serde(
+        default,
+        skip_serializing_if = "String::is_empty",
+        deserialize_with = "crate::utils::deserialize_null_string::deserialize"
+    )]
+    pub transaction_id: String,
+    #[serde(
+        default,
+        skip_serializing_if = "String::is_empty",
+        deserialize_with = "crate::utils::deserialize_null_string::deserialize"
+    )]
+    pub user_id: String,
 }
 
 #[derive(Serialize, Deserialize, PartialEq, Debug, Clone, JsonSchema)]
@@ -1805,8 +1932,12 @@ pub struct Reimbursement {
         deserialize_with = "crate::utils::deserialize_null_string::deserialize"
     )]
     pub currency: String,
-    #[serde(default, skip_serializing_if = "Option::is_none")]
-    pub id: Option<uuid::Uuid>,
+    #[serde(
+        default,
+        skip_serializing_if = "String::is_empty",
+        deserialize_with = "crate::utils::deserialize_null_string::deserialize"
+    )]
+    pub id: String,
     #[serde(
         default,
         skip_serializing_if = "String::is_empty",
@@ -1818,15 +1949,19 @@ pub struct Reimbursement {
         skip_serializing_if = "Vec::is_empty",
         deserialize_with = "crate::utils::deserialize_null_vector::deserialize"
     )]
-    pub receipts: Vec<uuid::Uuid>,
+    pub receipts: Vec<String>,
     #[serde(
         default,
         skip_serializing_if = "Option::is_none",
         deserialize_with = "crate::utils::date_format::deserialize"
     )]
     pub transaction_date: Option<chrono::NaiveDate>,
-    #[serde(default, skip_serializing_if = "Option::is_none")]
-    pub user_id: Option<uuid::Uuid>,
+    #[serde(
+        default,
+        skip_serializing_if = "String::is_empty",
+        deserialize_with = "crate::utils::deserialize_null_string::deserialize"
+    )]
+    pub user_id: String,
 }
 
 #[derive(Serialize, Deserialize, PartialEq, Debug, Clone, JsonSchema)]
@@ -1853,8 +1988,12 @@ pub struct PostCustomProviderEntityTypeLinkRequest {
     )]
     pub custom_id: String,
     /**
-     * The ID of the last entity of the previous page, used for pagination to get the next page.
+     * The OAuth2 token header
      */
-    #[serde(default, skip_serializing_if = "Option::is_none")]
-    pub ramp_id: Option<uuid::Uuid>,
+    #[serde(
+        default,
+        skip_serializing_if = "String::is_empty",
+        deserialize_with = "crate::utils::deserialize_null_string::deserialize"
+    )]
+    pub ramp_id: String,
 }
